# Table of contents

### Packages

eric7 | Package implementing the eric Python IDE.

### Modules

cleanupSource | Script for eric to clean up the source tree.
compileUiFiles | Script for eric to compile all .ui files to Python source.
create_windows_links | Installation script for the eric IDE and all eric related tools.
install | Installation script for the eric IDE and all eric related tools.
install-debugclients | Installation script for the eric debug clients.
install-i18n | Installation script for the eric IDE translation files.
setup | Module to prepare a distribution package for uploading to PyPI.
uninstall | Uninstallation script for the eric IDE and all eric related tools.
uninstall-debugclients | Unnstallation script for the eric debug clients.